@@ -37,35 +37,38 @@
 
 #define WD_MAX_PING_RESULT 256
 
-static double get_result (char * ping_data);
+static double get_result(char *ping_data);
 
 /**
  * check if IP address can be pinged.
  */
-bool wd_is_ip_exists(char* ip)
+bool
+wd_is_ip_exists(char *ip)
 {
-	pid_t pid;
-	int outputfd;
-	int status;
+	pid_t		pid;
+	int			outputfd;
+	int			status;
 
 	if (ip == NULL)
 		return false;
 
 	POOL_SETMASK(&AuthBlockSig);
 
-	pid = wd_issue_ping_command(ip,&outputfd);
-	if (pid <=  0)
+	pid = wd_issue_ping_command(ip, &outputfd);
+	if (pid <= 0)
 	{
 		POOL_SETMASK(&UnBlockSig);
 		return false;
 	}
 
-	for(;;)
+	for (;;)
 	{
-		pid_t sts = waitpid(pid, &status, 0);
+		pid_t		sts = waitpid(pid, &status, 0);
+
 		if (sts == pid)
 		{
-			bool ret = wd_get_ping_result(ip, status, outputfd);
+			bool		ret = wd_get_ping_result(ip, status, outputfd);
+
 			POOL_SETMASK(&UnBlockSig);
 			close(outputfd);
 			return ret;
@@ -76,8 +79,8 @@ bool wd_is_ip_exists(char* ip)
 		POOL_SETMASK(&UnBlockSig);
 		close(outputfd);
 		ereport(WARNING,
-			(errmsg("watchdog failed to ping host\"%s\"",ip),
-				 errdetail("waitpid() failed with reason \"%s\"", strerror(errno))));
+				(errmsg("watchdog failed to ping host\"%s\"", ip),
+				 errdetail("waitpid() failed with reason \"%m\"")));
 		return false;
 	}
 
@@ -89,24 +92,26 @@ bool wd_is_ip_exists(char* ip)
  * function issues the ping command using the execv system call
  * and return the pid of the process.
  */
-pid_t wd_issue_ping_command(char* hostname, int* outfd)
+pid_t
+wd_issue_ping_command(char *hostname, int *outfd)
 {
-	int status;
-	char * args[8];
-	int pid, i = 0;
-	int pfd[2];
-	char ping_path[WD_MAX_PATH_LEN];
+	int			status;
+	char	   *args[8];
+	int			pid,
+				i = 0;
+	int			pfd[2];
+	char		ping_path[WD_MAX_PATH_LEN];
 
-	snprintf(ping_path,sizeof(ping_path),"%s/ping",pool_config->ping_path);
+	snprintf(ping_path, sizeof(ping_path), "%s/ping", pool_config->ping_path);
 
 	ereport(DEBUG2,
-			(errmsg("watchdog trying to ping host \"%s\"",hostname)));
+			(errmsg("watchdog trying to ping host \"%s\"", hostname)));
 
 	if (pipe(pfd) == -1)
 	{
 		ereport(WARNING,
-			(errmsg("watchdog failed to ping host\"%s\"",hostname),
-				 errdetail("pipe open failed. reason: %s", strerror(errno))));
+				(errmsg("watchdog failed to ping host\"%s\"", hostname),
+				 errdetail("pipe open failed. reason: %m")));
 		return -1;
 	}
 
@@ -120,8 +125,8 @@ pid_t wd_issue_ping_command(char* hostname, int* outfd)
 	if (pid == -1)
 	{
 		ereport(WARNING,
-			(errmsg("watchdog failed to ping host\"%s\"",hostname),
-				 errdetail("fork() failed. reason: %s", strerror(errno))));
+				(errmsg("watchdog failed to ping host\"%s\"", hostname),
+				 errdetail("fork() failed. reason: %m")));
 		return -1;
 	}
 	if (pid == 0)
@@ -132,13 +137,13 @@ pid_t wd_issue_ping_command(char* hostname, int* outfd)
 		close(STDOUT_FILENO);
 		dup2(pfd[1], STDOUT_FILENO);
 		close(pfd[0]);
-		status = execv(ping_path,args);
+		status = execv(ping_path, args);
 
 		if (status == -1)
 		{
 			ereport(FATAL,
-				(errmsg("watchdog failed to ping host\"%s\"",hostname),
-					 errdetail("execv(%s) failed. reason: %s", ping_path, strerror(errno))));
+					(errmsg("watchdog failed to ping host\"%s\"", hostname),
+					 errdetail("execv(%s) failed. reason: %m", ping_path)));
 		}
 		exit(0);
 	}
@@ -151,19 +156,20 @@ pid_t wd_issue_ping_command(char* hostname, int* outfd)
  * The function is helper function and can be used with the
  * wd_issue_ping_command() function to identify if the ping command
  * was successful */
-bool wd_get_ping_result(char* hostname, int exit_status, int outfd)
+bool
+wd_get_ping_result(char *hostname, int exit_status, int outfd)
 {
-	/* First check the exit status of ping process*/
+	/* First check the exit status of ping process */
 	if (WIFEXITED(exit_status) == 0)
 	{
 		ereport(WARNING,
-			(errmsg("watchdog failed to ping host\"%s\"",hostname),
+				(errmsg("watchdog failed to ping host\"%s\"", hostname),
 				 errdetail("ping process exited abnormally")));
 	}
 	else if (WEXITSTATUS(exit_status) != 0)
 	{
 		ereport(WARNING,
-			(errmsg("watchdog failed to ping host\"%s\"",hostname),
+				(errmsg("watchdog failed to ping host\"%s\"", hostname),
 				 errdetail("ping process exits with code: %d", WEXITSTATUS(exit_status))));
 	}
 	else
@@ -190,7 +196,7 @@ bool wd_get_ping_result(char* hostname, int exit_status, int outfd)
 			return true;
 		}
 		ereport(WARNING,
-			(errmsg("ping host\"%s\" failed",hostname),
+				(errmsg("ping host\"%s\" failed", hostname),
 				 errdetail("average RTT value is not greater than zero")));
 		pfree(result.data);
 	}
@@ -201,12 +207,12 @@ bool wd_get_ping_result(char* hostname, int exit_status, int outfd)
  * Get average round-trip time of ping result.
  */
 static double
-get_result (char * ping_data)
+get_result(char *ping_data)
 {
-	char * sp = NULL;
-	char * ep = NULL;
-	int i;
-	double msec = 0;
+	char	   *sp = NULL;
+	char	   *ep = NULL;
+	int			i;
+	double		msec = 0;
 
 	if (ping_data == NULL)
 	{
@@ -215,26 +221,26 @@ get_result (char * ping_data)
 		return -1;
 	}
 	ereport(DEBUG1,
-		(errmsg("watchdog ping"),
+			(errmsg("watchdog ping"),
 			 errdetail("ping data: %s", ping_data)));
+
 	/*
-	 skip result until average data
-	 typical result of ping is as follows,
-	 "rtt min/avg/max/mdev = 0.045/0.045/0.046/0.006 ms"
-	 we can find the average data beyond the 4th '/'.
+	 * skip result until average data typical result of ping is as follows,
+	 * "rtt min/avg/max/mdev = 0.045/0.045/0.046/0.006 ms" we can find the
+	 * average data beyond the 4th '/'.
 	 */
 	sp = ping_data;
-	for ( i = 0 ; i < 4 ; i ++)
+	for (i = 0; i < 4; i++)
 	{
-		sp = strchr(sp,'/');
+		sp = strchr(sp, '/');
 		if (sp == NULL)
 		{
 			return -1;
 		}
-		sp ++;
+		sp++;
 	}
 
-	ep = strchr (sp,'/');
+	ep = strchr(sp, '/');
 	if (ep == NULL)
 	{
 		return -1;
@@ -244,12 +250,13 @@ get_result (char * ping_data)
 	errno = 0;
 
 	/* convert to numeric data from text */
-	msec = strtod(sp,(char **)NULL);
+	msec = strtod(sp, (char **) NULL);
 
 	if (errno != 0)
 	{
 		ereport(WARNING,
-				(errmsg("get_result: strtod() failed with reason \"%s\"", strerror(errno))));
+				(errmsg("get_result: strtod() failed"),
+				 errdetail("%m")));
 		return -1;
 	}
 
